## ACBox my little toolbox

[![PyPI version](https://img.shields.io/pypi/v/acbox.svg?color=blue)](https://pypi.org/project/acbox)
[![Python versions](https://img.shields.io/pypi/pyversions/acbox.svg)](https://pypi.org/project/acbox)
[![Codecov (with branch)](https://img.shields.io/codecov/c/github/cav71/acbox/beta%2F0.0.0)](https://app.codecov.io/gh/cav71/acbox/tree/beta%2F0.0.0)
[![Build](https://github.com/cav71/acbox/actions/workflows/beta.yml/badge.svg)](https://github.com/cav71/acbox/actions/workflows/beta.yml)


[![License - MIT](https://img.shields.io/badge/license-MIT-9400d3.svg)](https://spdx.org/licenses/)
![PyPI - Downloads](https://img.shields.io/pypi/dm/acbox)
[![Mypy](https://img.shields.io/badge/types-Mypy-blue.svg)](https://mypy-lang.org/)
[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)



### Development

```
python3.13 -m venv .venv
source .venv/bin/activate
```

```
python -m pip install --upgrade pip
python -m pip install --group dev
pre-commit install
```

Ready.
